# The Countdown Simulation

## Introduction
This project is a model answer from the first coursework assignment set for ECM1400 in 2019. The purpose is to demonstrate how code can not only be used to run locally but can be published and extended within the Python ecosysetm.

The code in this project runs a simulation of the channel 4 gameshow countdown.

## Prerequisites
To run this code you will need Python 3.7 or above.

  - Author: Matt Collison - mcollison
  - License: Creative Commons 4.0 https://creativecommons.org/licenses/by/4.0/

## User instructions
To use the repository install and import the package as shown below.

$ pip install countdown-pkg-mcollison

from countdown import ca1_model_answer as countdown
countdown.tests()
countdown.game_play()
